Execution

Struct Execution 

pub struct Execution<'gc, 'a> { /* private fields */ }
Execution state passed to callbacks when they are run by an Executor.

Implementations

Source

impl<'gc, 'a> Execution<'gc, 'a>

pub fn fuel(&mut self) -> &mut Fuel

The fuel parameter passed to Executor::step.

pub fn current_thread(&self) -> CurrentThread<'gc>

The curently executing Thread.

pub fn executor(&self) -> Executor<'gc>

The curently running Executor.

Do not call methods on this from callbacks! This is provided only for identification purposes, so that callbacks can identify which executor that is currently executing them, or to store the pointer somewhere.

pub fn upper_lua_frame(&self) -> Option<UpperLuaFrame<'gc>>

If the function we are returning to is Lua, returns information about the Lua frame we are returning to.