Value

Enum Value 

pub enum Value<'gc> {
    Nil,
    Boolean(bool),
    Integer(i64),
    Number(f64),
    String(String<'gc>),
    Table(Table<'gc>),
    Function(Function<'gc>),
    Thread(Thread<'gc>),
    UserData(UserData<'gc>),
}

Variants



Nil



Boolean(bool)



Integer(i64)



Number(f64)



String(String<'gc>)



Table(Table<'gc>)



Function(Function<'gc>)



Thread(Thread<'gc>)



UserData(UserData<'gc>)

Implementations

Source

impl<'gc> Value<'gc>

pub fn type_name(self) -> &'static str

pub fn display<W: Write>(self, w: W) -> Result<(), Error>

pub fn is_nil(self) -> bool

pub fn to_bool(self) -> bool

Lua nil and false are false, anything else is true.

pub fn not(self) -> Value<'gc>

pub fn to_number(self) -> Option<f64>

Interprets Numbers, Integers, and Strings as a Number, if possible.

pub fn to_integer(self) -> Option<i64>

Interprets Numbers, Integers, and Strings as an Integer, if possible.

pub fn to_constant(self) -> Option<Constant<String<'gc>>>