pub struct Execution<'gc, 'a> { /* private fields */ }Expand description
Execution state passed to callbacks when they are run by an Executor.
Implementations
Sourceimpl<'gc, 'a> Execution<'gc, 'a>
impl<'gc, 'a> Execution<'gc, 'a>
Sourcepub fn current_thread(&self) -> CurrentThread<'gc>
pub fn current_thread(&self) -> CurrentThread<'gc>
The curently executing Thread.
Sourcepub fn executor(&self) -> Executor<'gc>
pub fn executor(&self) -> Executor<'gc>
The curently running Executor.
Do not call methods on this from callbacks! This is provided only for identification purposes, so that callbacks can identify which executor that is currently executing them, or to store the pointer somewhere.
Sourcepub fn upper_lua_frame(&self) -> Option<UpperLuaFrame<'gc>>
pub fn upper_lua_frame(&self) -> Option<UpperLuaFrame<'gc>>
If the function we are returning to is Lua, returns information about the Lua frame we are returning to.