pub enum Value<'gc> {
Nil,
Boolean(bool),
Integer(i64),
Number(f64),
String(String<'gc>),
Table(Table<'gc>),
Function(Function<'gc>),
Thread(Thread<'gc>),
UserData(UserData<'gc>),
}Variants
Nil
Boolean(bool)
Integer(i64)
Number(f64)
String(String<'gc>)
Table(Table<'gc>)
Function(Function<'gc>)
Thread(Thread<'gc>)
UserData(UserData<'gc>)
Implementations
Sourceimpl<'gc> Value<'gc>
impl<'gc> Value<'gc>
pub fn type_name(self) -> &'static str
pub fn display<W: Write>(self, w: W) -> Result<(), Error>
pub fn is_nil(self) -> bool
pub fn not(self) -> Value<'gc>
Sourcepub fn to_number(self) -> Option<f64>
pub fn to_number(self) -> Option<f64>
Interprets Numbers, Integers, and Strings as a Number, if possible.
Sourcepub fn to_integer(self) -> Option<i64>
pub fn to_integer(self) -> Option<i64>
Interprets Numbers, Integers, and Strings as an Integer, if possible.
pub fn to_constant(self) -> Option<Constant<String<'gc>>>